cocos.audio.SDL.timer module — cocos v0.6.5 documentation

# cocos.audio.SDL.timer module

Time management routines.

`SDL_AddTimer`(interval, callback, param)

  Add a new timer to the pool of timers already running.

    Parameters: | interval : int The interval before calling the callback, in milliseconds. callback : function The callback function. It is passed the current timer interval, in millseconds, and returns the next timer interval, in milliseconds. If the returned value is the same as the one passed in, the periodic alarm continues, otherwise a new alarm is scheduled. If the callback returns 0, the periodic alarm is cancelled. An example callback function is:
        def timer_callback(interval, param):
            print('timer called after %d ms.' % interval)
            return 1000     # call again in 1 second
  param : any A value passed to the callback function.
  Return type: | int
  Returns: | the timer ID

`SDL_RemoveTimer`(t)

  Remove one of the multiple timers knowing its ID.

  Parameters: | t : int The timer ID, as returned by SDL_AddTimer.

`SDL_SetTimer`(interval, callback)

  Set a callback to run after the specified number of milliseconds has elapsed.

  The callback function is passed the current timer interval and returns the next timer interval. If the returned value is the same as the one passed in, the periodic alarm continues, otherwise a new alarm is scheduled. If the callback returns 0, the periodic alarm is cancelled.

  To cancel a currently running timer, call `SDL_SetTimer(0, None)`.

  The timer callback function may run in a different thread than your main code, and so shouldn’t call any functions from within itself.

  The maximum resolution of this timer is 10 ms, which means that if you request a 16 ms timer, your callback will run approximately 20 ms later on an unloaded system. If you wanted to set a flag signaling a frame update at 30 frames per second (every 33 ms), you might set a timer for 30 ms:

      SDL_SetTimer((33/10)*10, flag_update)

  If you use this function, you need to pass SDL_INIT_TIMER to SDL_Init.

  Under UNIX, you should not use raise or use SIGALRM and this function in the same program, as it is implemented using `setitimer`. You also should not use this function in multi-threaded applications as signals to multi-threaded apps have undefined behavior in some implementations.

  Parameters: | interval : int Interval before callback, in milliseconds. callback : function Callback function should accept one argument, the number of milliseconds elapsed, and return the next timer interval, in milliseconds.